# TaBB

> [!WARNING]
> TaBB has an alpha devlopment status. This package is untested and the api is subject to change. Use at your own risk.

Trevor's argparse but better. CLI and configuration using Python type hints.

[![PyPI - Version](https://img.shields.io/pypi/v/tabb.svg)](https://pypi.org/project/tabb)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/tabb.svg)](https://pypi.org/project/tabb)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install tabb
```

## License

`tabb` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
